Name:           maven
Version:        3.3.9
Release:        %mkrel 13
Summary:        Java project management and project comprehension tool
License:        ASL 2.0
URL:            http://maven.apache.org/
BuildArch:      noarch
Group:          Development/Java
Source0:        http://archive.apache.org/dist/%{name}/%{name}-3/%{version}/source/apache-%{name}-%{version}-src.tar.gz
Source1:        maven-bash-completion
Source2:        mvn.1
Source200:      %{name}-script

Patch0:         0001-Force-SLF4J-SimpleLogger-re-initialization.patch

# If XMvn is part of the same RPM transaction then it should be
# installed first to avoid triggering rhbz#1014355.
OrderWithRequires: xmvn

BuildRequires:  maven-local

BuildRequires:  aether-api >= 1:0
BuildRequires:  aether-connector-basic >= 1:0
BuildRequires:  aether-impl >= 1:0
BuildRequires:  aether-spi >= 1:0
BuildRequires:  aether-util >= 1:0
BuildRequires:  aether-transport-wagon >= 1:0
BuildRequires:  aopalliance
BuildRequires:  apache-commons-cli
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-codec
BuildRequires:  apache-commons-jxpath
BuildRequires:  apache-commons-logging
BuildRequires:  apache-resource-bundles
BuildRequires:  atinject
BuildRequires:  buildnumber-maven-plugin
BuildRequires:  cglib
BuildRequires:  easymock3
BuildRequires:  google-guice >= 3.1.6
BuildRequires:  hamcrest
BuildRequires:  httpcomponents-core
BuildRequires:  httpcomponents-client
BuildRequires:  jsoup
BuildRequires:  jsr-305
BuildRequires:  junit
BuildRequires:  maven-assembly-plugin
BuildRequires:  maven-compiler-plugin
BuildRequires:  maven-install-plugin
BuildRequires:  maven-jar-plugin
BuildRequires:  maven-javadoc-plugin
BuildRequires:  maven-parent
BuildRequires:  maven-remote-resources-plugin
BuildRequires:  maven-resources-plugin
BuildRequires:  maven-site-plugin
BuildRequires:  maven-surefire-plugin
BuildRequires:  maven-wagon-file
BuildRequires:  maven-wagon-http
BuildRequires:  maven-wagon-http-shared
BuildRequires:  maven-wagon-provider-api
BuildRequires:  objectweb-asm
BuildRequires:  plexus-cipher
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-containers-component-annotations
BuildRequires:  plexus-containers-component-metadata >= 1.5.5
BuildRequires:  plexus-interpolation
BuildRequires:  plexus-sec-dispatcher
BuildRequires:  plexus-utils >= 3.0.10
BuildRequires:  sisu-inject >= 1:0.1
BuildRequires:  sisu-plexus >= 1:0.1
BuildRequires:  sisu-mojos
BuildRequires:  slf4j
BuildRequires:  xmlunit
BuildRequires:  mvn(ch.qos.logback:logback-classic)
BuildRequires:  mvn(org.mockito:mockito-core)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)

# Theoretically Maven might be usable with just JRE, but typical Maven
# workflow requires full JDK, so we recommend it here.
Recommends:     java-devel

# XMvn does generate auto-requires, but explicit requires are still
# needed because some symlinked JARs are not present in Maven POMs or
# their dependency scope prevents them from being added automatically
# by XMvn.  It would be possible to explicitly specify only
# dependencies which are not generated automatically, but adding
# everything seems to be easier.
Requires:       aether-api
Requires:       aether-connector-basic
Requires:       aether-impl
Requires:       aether-spi
Requires:       aether-transport-wagon
Requires:       aether-util
Requires:       aopalliance
Requires:       apache-commons-cli
Requires:       apache-commons-io
Requires:       apache-commons-lang
Requires:       apache-commons-lang3
Requires:       apache-commons-codec
Requires:       apache-commons-logging
Requires:       atinject
Requires:       google-guice
Requires:       guava
Requires:       httpcomponents-client
Requires:       httpcomponents-core
Requires:       jsoup
Requires:       jsr-305
Requires:       maven-wagon-file
Requires:       maven-wagon-http
Requires:       maven-wagon-http-shared
Requires:       maven-wagon-provider-api
Requires:       objectweb-asm
Requires:       plexus-cipher
Requires:       plexus-classworlds
Requires:       plexus-containers-component-annotations
Requires:       plexus-interpolation
Requires:       plexus-sec-dispatcher
Requires:       plexus-utils
Requires:       sisu-inject
Requires:       sisu-plexus
Requires:       slf4j

# Temporary fix for broken sisu
Requires:       cdi-api
BuildRequires:  cdi-api

%description
Maven is a software project management and comprehension tool. Based on the
concept of a project object model (POM), Maven can manage a project's build,
reporting and documentation from a central piece of information.

%package        javadoc
Summary:        API documentation for %{name}
Group:          Documentation

%description    javadoc
%{summary}.

%prep
%setup -q -n apache-%{name}-%{version}%{?ver_add}
%patch0 -p1

# not really used during build, but a precaution
rm maven-ant-tasks-*.jar

# Use Eclipse Sisu plugin
sed -i s/org.sonatype.plugins/org.eclipse.sisu/ maven-core/pom.xml

# fix for animal-sniffer (we don't generate 1.5 signatures)
sed -i 's:check-java-1.5-compat:check-java-1.6-compat:' pom.xml

rm -f apache-maven/src/bin/*.bat
sed -i 's:\r::' apache-maven/src/conf/settings.xml

# Update shell scripts to use unversioned classworlds
sed -i -e s:'-classpath "${M2_HOME}"/boot/plexus-classworlds-\*.jar':'-classpath "${M2_HOME}"/boot/plexus-classworlds.jar':g \
        apache-maven/src/bin/mvn*

# Disable QA plugins which are not useful for us
%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :apache-rat-plugin

# logback is not really needed by maven in typical use cases, so set
# its scope to provided
%pom_xpath_inject "pom:dependency[pom:artifactId='logback-classic']" "<scope>provided</scope>" maven-embedder


%build
# Put all JARs in standard location, but create symlinks in Maven lib
# directory so that Plexus Classworlds can find them.
%mvn_file ":{*}:jar:" %{name}/@1 %{_datadir}/%{name}/lib/@1

%mvn_build -- -Dproject.build.sourceEncoding=UTF-8 -X -Dsisu.debug=true

mkdir m2home
(cd m2home
    tar --delay-directory-restore -xvf ../apache-maven/target/*tar.gz
    chmod -R +rwX apache-%{name}-%{version}%{?ver_add}
    chmod -x apache-%{name}-%{version}%{?ver_add}/conf/settings.xml
)


%install
%mvn_install

export M2_HOME=$(pwd)/m2home/apache-maven-%{version}%{?ver_add}

install -d -m 755 %{buildroot}%{_datadir}/%{name}/bin
install -d -m 755 %{buildroot}%{_datadir}/%{name}/conf
install -d -m 755 %{buildroot}%{_datadir}/%{name}/boot
install -d -m 755 %{buildroot}%{_datadir}/%{name}/lib/ext
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{_sysconfdir}/%{name}
install -d -m 755 %{buildroot}%{_datadir}/bash-completion/completions
install -d -m 755 %{buildroot}%{_mandir}/man1

for cmd in mvn mvnDebug mvnyjp; do
    sed s/@@CMD@@/$cmd/ %{SOURCE200} >%{buildroot}%{_bindir}/$cmd
    echo ".so man1/mvn.1" >%{buildroot}%{_mandir}/man1/$cmd.1
done
install -p -m 644 %{SOURCE2} %{buildroot}%{_mandir}/man1
install -p -m 644 %{SOURCE1} %{buildroot}%{_datadir}/bash-completion/completions/mvn
mv $M2_HOME/bin/m2.conf %{buildroot}%{_sysconfdir}
ln -sf %{_sysconfdir}/m2.conf %{buildroot}%{_datadir}/%{name}/bin/m2.conf
mv $M2_HOME/conf/settings.xml %{buildroot}%{_sysconfdir}/%{name}
ln -sf %{_sysconfdir}/%{name}/settings.xml %{buildroot}%{_datadir}/%{name}/conf/settings.xml
mv $M2_HOME/conf/logging %{buildroot}%{_sysconfdir}/%{name}
ln -sf %{_sysconfdir}/%{name}/logging %{buildroot}%{_datadir}/%{name}/conf

cp -a $M2_HOME/bin/* %{buildroot}%{_datadir}/%{name}/bin

ln -sf $(build-classpath plexus/classworlds) \
    %{buildroot}%{_datadir}/%{name}/boot/plexus-classworlds.jar

(cd %{buildroot}%{_datadir}/%{name}/lib
    build-jar-repository -s -p . \
        aether/aether-api \
        aether/aether-connector-basic \
        aether/aether-impl \
        aether/aether-spi \
        aether/aether-transport-wagon \
        aether/aether-util \
        aopalliance \
        cdi-api \
        commons-cli \
        commons-io \
        commons-lang \
        commons-lang3 \
        guava \
        atinject \
        jsoup/jsoup \
        jsr-305 \
        org.eclipse.sisu.inject \
        org.eclipse.sisu.plexus \
        plexus/plexus-cipher \
        plexus/containers-component-annotations \
        plexus/interpolation \
        plexus/plexus-sec-dispatcher \
        plexus/utils \
        google-guice-no_aop \
        slf4j/api \
        slf4j/simple \
        maven-wagon/file \
        maven-wagon/http-shaded \
        maven-wagon/http-shared \
        maven-wagon/provider-api \
        \
        httpcomponents/httpclient \
        httpcomponents/httpcore \
        commons-logging \
        commons-codec \
        objectweb-asm/asm \
)


%files -f .mfiles
%doc LICENSE NOTICE README.md
%{_datadir}/%{name}
%attr(0755,root,root) %{_bindir}/mvn*
%dir %{_javadir}/%{name}
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/logging
%config(noreplace) %{_sysconfdir}/m2.conf
%config(noreplace) %{_sysconfdir}/%{name}/settings.xml
%config(noreplace) %{_sysconfdir}/%{name}/logging/simplelogger.properties
%{_datadir}/bash-completion/completions/mvn
%{_mandir}/man1/mvn*.1.*

%files javadoc -f .mfiles-javadoc
%doc LICENSE NOTICE



%changelog
* Fri Apr 29 2016 daviddavid <daviddavid> 3.3.9-13.mga6
+ Revision: 1007667
- Force SLF4J SimpleLogger re-initialization
- Resolves: rhbz#1324832

  + neoclust <neoclust>
    - Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 3.3.9-11.mga6
+ Revision: 977336
- First rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 3.3.9-10.mga6
+ Revision: 975273
- First rebuild of the bootstrap
- sync package maven with fedora
- Fix symlinks: add commons-lang3 and remove geronimo-annotation

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

  + zezinho <zezinho>
    - fix man
    - new version

  + daviddavid <daviddavid>
    - sync with fc24 (update to 3.3.3)

  + pterjan <pterjan>
    - Obsolete apt-maven-plugin

* Tue Nov 04 2014 dmorgan <dmorgan> 3.2.2-3.mga5
+ Revision: 795486
- Fix Requires

* Thu Oct 30 2014 dmorgan <dmorgan> 3.2.2-2.mga5
+ Revision: 794717
- Rebuild after bootstrap
- New version

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-6.mga5
+ Revision: 743599
- Second Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Obsolete maven-ant-tasks which doesnot support maven3

* Fri Oct 03 2014 pterjan <pterjan> 3.1.1-5.mga5
+ Revision: 736267
- Revert workaround, the path is now correct
- Workaround jar files being install in /usr/lib instead of /usr/share
- Revert to 3.1.1

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Mon Sep 08 2014 pterjan <pterjan> 3.2.3-1.mga5
+ Revision: 673492
- 3.2.3
- Sync with Fedora

* Wed Sep 03 2014 dmorgan <dmorgan> 3.1.1-4.mga5
+ Revision: 671690
- Fix Build with google-guice

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1.1-3.mga5
+ Revision: 636501
- Add objectweb-pom as require

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1.1-2.mga5
+ Revision: 636313
- Rebuild with fixed xmvn

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1.1-1.mga5
+ Revision: 636300
- Remove use of OrderWithRequires for the moment
- Sync with fedora ( BR / Requires ).
- Fix patches
- New version
- Rebuild against current java stack
- Revert to version 3.1.0
- New version

  + joequant <joequant>
    - rebuild to match dependencies

* Tue Jan 14 2014 dmorgan <dmorgan> 3.1.0-14.mga4
+ Revision: 566540
- Rebuild against fixed xbean

* Mon Dec 23 2013 dmorgan <dmorgan> 3.1.0-13.mga4
+ Revision: 560253
- Add maven-local as require for mageia4, we will finish BR migration for mga5

* Wed Dec 04 2013 joequant <joequant> 3.1.0-12.mga4
+ Revision: 555102
- add http-lightweight component which is necessary for server downloads

* Mon Oct 21 2013 umeabot <umeabot> 3.1.0-11.mga4
+ Revision: 539528
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 dmorgan <dmorgan> 3.1.0-10.mga4
+ Revision: 492381
- Rebuild against current jar

* Fri Sep 27 2013 dmorgan <dmorgan> 3.1.0-9.mga4
+ Revision: 487430
- Add patch for MNG-5503
- Resolves: rhbz#991454
- Build with easymock3

* Thu Sep 26 2013 dmorgan <dmorgan> 3.1.0-8.mga4
+ Revision: 486632
- Remove exclude

* Thu Sep 26 2013 dmorgan <dmorgan> 3.1.0-7.mga4
+ Revision: 486631
- Update Aether to 0.9.0.M3

* Mon Sep 23 2013 dmorgan <dmorgan> 3.1.0-6.mga4
+ Revision: 484382
- Synchronize JAR list in lib/ with upstream release
- Remove test dependencies on aopalliance and cglib
- Prepare for update to Aether 0.9.0.M3
- Install simplelogger.properties into %%{_sysconfdir}
- New version 3.1.0

* Wed Sep 18 2013 dmorgan <dmorgan> 3.0.5-10.mga4
+ Revision: 481232
- Use sonatype-aether symlinks

* Sat Jul 13 2013 dmorgan <dmorgan> 3.0.5-9.mga4
+ Revision: 453645
- Add codehaus-parent as Require in maven

* Sat Jul 13 2013 dmorgan <dmorgan> 3.0.5-8.mga4
+ Revision: 453618
- Requires maven-local during the transition

* Fri Jul 12 2013 dmorgan <dmorgan> 3.0.5-7.mga4
+ Revision: 453363
- New version

* Wed Jul 10 2013 dmorgan <dmorgan> 3.0.4-30.mga4
+ Revision: 452573
- In maven-script do not override M2_HOME if already set

* Sat Jan 12 2013 umeabot <umeabot> 3.0.4-29.mga3
+ Revision: 359569
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 dmorgan <dmorgan> 3.0.4-28.mga3
+ Revision: 340011
- Add codehaus-parent as requires

  + pterjan <pterjan>
    - Add missing BuildRequires

* Sat Dec 01 2012 dmorgan <dmorgan> 3.0.4-27.mga3
+ Revision: 324056
- Requires maven-local and remove files

* Wed Sep 12 2012 dmorgan <dmorgan> 3.0.4-4.mga3
+ Revision: 292648
- Sync with fedora maven

* Mon Sep 10 2012 dmorgan <dmorgan> 3.0.4-3.mga3
+ Revision: 291582
- Obsolete and provide maven2

* Mon Jul 16 2012 dmorgan <dmorgan> 3.0.4-2.mga3
+ Revision: 271275
- Make package noarch again to simplify bootstrapping

* Mon Jul 09 2012 dmorgan <dmorgan> 3.0.4-1.mga3
+ Revision: 268995
- Make javadoc noarch
- Make compilation source level 1.5
- Fix borked tarball unpacking (reason unknown)
- New version 3.0.4

* Mon Dec 26 2011 dmorgan <dmorgan> 3.0.3-15.mga2
+ Revision: 187695
- R/BR maven2-common-poms

* Fri Dec 23 2011 dmorgan <dmorgan> 3.0.3-14.mga2
+ Revision: 186275
- Fix test scope skipping ( From Fedora)

* Sat Dec 10 2011 dmorgan <dmorgan> 3.0.3-9.mga2
+ Revision: 180007
- Try to readd some deps

* Sat Dec 10 2011 dmorgan <dmorgan> 3.0.3-7.mga2
+ Revision: 179907
- Remove unnecessary deps causing problems from lib/
- Add utf-8 source encoding patch
- Disable debug package creation
- Change to arch specific since we are using _libdir for _jnidir
- Add bash completion (RHBZ #706856)

* Tue Jul 19 2011 dmorgan <dmorgan> 3.0.3-5.mga2
+ Revision: 126422
- Re enable maven-paret R/BR

* Tue Jul 19 2011 dmorgan <dmorgan> 3.0.3-4.mga2
+ Revision: 126392
- Disable R/BR for now
- Keep macros for now
- Backport fixes from fedora
- Fix handling of fallback default_poms
- Add empty-dep into maven package to not require maven2 version
- Process fragments in alphabetical order
- Add maven-parent to BR/R
- Add resolving from jnidir and java-jni
- Expect fragments in /usr/share/maven-fragments
- Resolve poms also from /usr/share/maven-poms
- Process fragments directly instead of maven2-depmap.xml(fedora)
- Add help to mvn-rpmbuild and mvn-local (rhbz#710448)
- Improve and clean up depmap handling for m2/m3 repos (fedora)

* Thu Apr 28 2011 dmorgan <dmorgan> 3.0.3-3.mga1
+ Revision: 93275
- Enable MAVEN_OPTS override in scripts ( From fedora )

* Thu Apr 28 2011 dmorgan <dmorgan> 3.0.3-2.mga1
+ Revision: 92622
- Rebuild after bootstrapping
- imported package maven


* Fri Mar  4 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.3-1
- Update to 3.0.3
- Add ext subdirectory to lib

* Tue Mar  1 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.3-0.1.rc1
- Update to 3.0.3rc1
- Enable tests again

* Thu Feb 10 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.2-2
- Added mvn-rpmbuild script to be used in spec files
- mvn-local is now mixed mode (online with javadir priority)
- Changed mvn.jpp to mvn.local

* Fri Jan 28 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0.2-1
- Update to latest version (3.0.2)
- Ignore test failures temporarily

* Wed Jan 12 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-6
- Fix bug #669034

* Tue Jan 11 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-5
- Fix bugs #667625 #667614 and #667636
- Install maven metadata so they are not downloaded when mvn is run
- Rename mvn3-local to mvn-local
- Add more comments to resolver patch

* Tue Dec 21 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-4
- Add fedora local resolver
- Fix quoting of arguments to mvn scripts
- Add javadoc subpackage
- Make jars versionless and remove unneeded clean section

* Wed Dec  1 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-3
- Remove maven-ant-tasks jar in prep
- Make fragment file as %%config

* Tue Nov 16 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-2
- Added apache-commons-parent to BR after commons changes

* Tue Oct 12 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 3.0-1
- Initial package with vanilla maven (no jpp mode yet)
